Skip to contents

Get the athletes for an account. Inactive players will only be included if includeInactive parameter is set to TRUE.

Usage

get_athletes(includeInactive = FALSE)

Arguments

includeInactive

FALSE by default to exclude inactive players in database. Set to TRUE if you want inactive players included in the return.

Value

Response will be a data frame containing the athletes that match this query. Each athlete includes the following variables:

Column NameTypeDescription
idchrathlete's unique ID
namechrathlete's given name (First Last)
activeboolathlete is active (TRUE)
teamschrteam ids separated by ","
groupschrgroup ids separated by ","
imagechrURL to athlete's profile image
positionchrathlete's position
dobchrathlete's date of birth
sportchrathlete's sport
heightchrathlete's height
lastTestedOnchrdate of athlete's last test
externalchrexternal properties will have a column of their name with the appropriate values for the athlete of NA if it does not apply

Examples

if (FALSE) { # \dontrun{
# This is an example of how the function would be called. If you only wish to call active players,
# you don't need to provide any parameters.

df_athletes <- get_athletes()

# If you want to include all athletes, including inactive athletes, include the optional
# `includeInactive` parameter.

df_wInactive <- get_athletes( includeInactive = TRUE)

} # }